@@ -17,8 +17,8 @@ class WebSocket:
     procedures = []
     logger = logging.getLogger(__name__)
 
-    @staticmethod
-    def recv(**kwrags):
+    @classmethod
+    def recv(cls, **kwrags):
         host = kwrags.get('host')
         logger = kwrags.get('logger')
 
@@ -67,8 +67,8 @@ class WebSocket:
             settings.LOCKS.release(key)
             return None
 
-    @staticmethod
-    def send_message(**kwrags):
+    @classmethod
+    def send_message(cls, **kwrags):
         host = kwrags.get('host')
         logger = kwrags.get('logger')
 
@@ -116,8 +116,8 @@ class WebSocket:
             del exc_info
             settings.LOCKS.release(key)
 
-    @staticmethod
-    def full_refresh_grid(grid_id):
+    @classmethod
+    def full_refresh_grid(cls, grid_id):
         WebSocket.send_message(
             host=settings.WS_HOST,
             port=settings.WS_PORT,
@@ -126,8 +126,8 @@ class WebSocket:
             logger=logger
         )
 
-    @staticmethod
-    def row_refresh_grid(grid_id, records):
+    @classmethod
+    def row_refresh_grid(cls, grid_id, records):
         if not isinstance(records, list):
             if isinstance(records, dict):
                 records = [records]
@@ -142,8 +142,8 @@ class WebSocket:
             logger=logger
         )
 
-    @staticmethod
-    def refresh_progres(grid_id, pk_filed_name, pk_value, progress_field_name, progress_done):
+    @classmethod
+    def refresh_progres(cls, grid_id, pk_filed_name, pk_value, progress_field_name, progress_done):
 
         record = dict()
         setAttr(record, pk_filed_name, pk_value)
@@ -154,23 +154,23 @@ class WebSocket:
             records=[record]
         )
 
-    @staticmethod
-    def send_warning_message(**kwrags):
+    @classmethod
+    def send_warning_message(cls, **kwrags):
         setAttr(kwrags, 'type', 'warn')
         WebSocket.send_typing_message(**kwrags)
 
-    @staticmethod
-    def send_info_message(**kwrags):
+    @classmethod
+    def send_info_message(cls, **kwrags):
         setAttr(kwrags, 'type', 'info')
         WebSocket.send_typing_message(**kwrags)
 
-    @staticmethod
-    def send_ask_message(**kwrags):
+    @classmethod
+    def send_ask_message(cls, **kwrags):
         setAttr(kwrags, 'type', 'ask')
         WebSocket.send_typing_message(**kwrags)
 
-    @staticmethod
-    def send_typing_message(**kwrags):
+    @classmethod
+    def send_typing_message(cls, **kwrags):
 
         type = kwrags.get('type')
         if not type:
