@@ -15,8 +15,8 @@ class Chat_user_user_themeQuerySet(AuditQuerySet):
 
 class Chat_user_user_themeManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
         }
